﻿using Infragistics.UltraChart.Core;
using Infragistics.UltraChart.Core.Primitives;
using Infragistics.UltraChart.Core.Util;
using Infragistics.UltraChart.Resources;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;
using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace CustomColumnColors
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
            ultraChart1.FillSceneGraph += ultraChart1_FillSceneGraph;
        }

        void ultraChart1_FillSceneGraph(object sender, Infragistics.UltraChart.Shared.Events.FillSceneGraphEventArgs e)
        {

            IAdvanceAxis xaxis = e.Grid["X"] as IAdvanceAxis;
            IAdvanceAxis yaxis = e.Grid["Y"] as IAdvanceAxis;

            if (xaxis == null)
            {
                return;
            }

            int xloc1 = (int)xaxis.MapMinimum;
            int xloc2 = (int)xaxis.MapMaximum;
            int yloc = (int)yaxis.Map(6);

            Box b = new Box(new Point(xloc1, yloc - 2), xloc2 - xloc1, 5, new LineStyle(LineCapStyle.NoAnchor, LineCapStyle.NoAnchor, LineDrawStyle.Solid));
            b.PE.Fill = Color.LightGreen;
            b.Value = 6d; // has to be a double for the value
            b.Caps = PCaps.HitTest | PCaps.Skin | PCaps.Tooltip;
            b.Chart = e.ChartCore.ChartType;
            b.Layer = e.ChartCore.GetChartLayer();
            b.Row = b.Column = -1; // have to set these to -1
            
            e.SceneGraph.Add(b);

        }

        private void Form1_Load(object sender, EventArgs e)
        {
            ultraChart1.ChartType = Infragistics.UltraChart.Shared.Styles.ChartType.ColumnChart;
            ultraChart1.DataSource = GetEmployeeOptions();
            Hashtable myHashTable = new Hashtable();
            myHashTable.Add("MyLabel", new CustomToolTips());
            this.ultraChart1.LabelHash = myHashTable;
            this.ultraChart1.Tooltips.Format = TooltipStyle.Custom;
            this.ultraChart1.Tooltips.FormatString = "<MyLabel>";
            this.ultraChart1.Tooltips.Overflow = TooltipOverflow.ChartArea;
            ChartOverrides();
        }

        private void ChartOverrides()
        {
            //Note, Overrides override eachother.

            Override override1 = new Override();
            override1.Column = -2; // match all data columns
            override1.Row = -2; // match all rows;
            override1.PE =
              new PaintElement(Color.Blue);
            this.ultraChart1.Override.Add(override1);
            Override override2 = new Override();
            override2.Column = 0; // column #1 only
            override2.Row = 1; // modify first data row
            override2.PE = new PaintElement(Color.Red);
            this.ultraChart1.Override.Add(override2);
            Override override3 = new Override();
            override3.Column = 0; // column #1 only
            override3.Row = 7; // row 7 only
            override3.PE = new PaintElement(Color.Red);
            this.ultraChart1.Override.Add(override3);
            this.ultraChart1.Override.Enabled = true;
        }

        private DataTable GetEmployeeOptions()
        {
            DataTable dtData = new DataTable("EmployeeOptions");

            dtData.Columns.Add("ID", typeof(int));
            
            dtData.Columns.Add("Option", typeof(string));
            dtData.Columns.Add("Description", typeof(string));


            for (int i = 0; i < 8; i++)
            {
                dtData.Rows.Add(new object[] { i +1, string.Format("Day {0}", i), String.Format("Option Description {0}", i) });
            }

            dtData.PrimaryKey = new DataColumn[] { dtData.Columns["OptionID"] };

            return dtData;
        }
    }

    class CustomToolTips : IRenderLabel
    {
        public string ToString(System.Collections.Hashtable context)
        {
            int row = (int)context["DATA_ROW"];
            int col = (int)context["DATA_COLUMN"];
            if (row == -1 && col == -1)
            {
                return string.Format("The average is: {0}", context["DATA_VALUE"]);
            }
            return (string)context["ITEM_LABEL"] + ((double)context["DATA_VALUE"]);
        }
    }

 
}
